@@ -33,4 +33,8 @@ pub const QTEST_OUTPUT_FILE: &str= ".qtest/quicktest_output.txt";
 pub const QTEST_ERROR_FILE: &str= ".qtest/quicktest_error.txt";
 
 pub const QTEST_EXPECTED_FILE: &str= ".qtest/expected_testcase.txt";
-pub const QTEST_CHECKER_FILE: &str= ".qtest/checker_testcase.txt";
\ No newline at end of file
+pub const QTEST_CHECKER_FILE: &str= ".qtest/checker_testcase.txt";
+
+pub const PREFIX_TLE_FILES: &str = "testcase_tle";
+pub const PREFIX_WA_FILES: &str = "testcase_wa";
+pub const PREFIX_RTE_FILES: &str = "testcase_rte";
\ No newline at end of file
