@@ -6,6 +6,4 @@
 
 mod tle_subcommand;
 mod cmp_subcommand;
-mod check_subcommand;
-mod test_utilities;
-mod test_constants;
\ No newline at end of file
+mod check_subcommand;
\ No newline at end of file
